@@ -9,8 +9,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_MODELS_KEYLISTMODEL_H__
-#define __KLEOPATRA_MODELS_KEYLISTMODEL_H__
+#pragma once
 
 #include <QAbstractItemModel>
 
@@ -73,10 +72,10 @@ public Q_SLOTS:
     void removeKey(const GpgME::Key &key);
 
     void setGroups(const std::vector<KeyGroup> &groups);
-    QModelIndex addGroup(const KeyGroup &group);
-    bool removeGroup(const KeyGroup &group);
+    QModelIndex addGroup(const Kleo::KeyGroup &group);
+    bool removeGroup(const Kleo::KeyGroup &group);
 
-    void clear(ItemTypes types = All);
+    void clear(Kleo::AbstractKeyListModel::ItemTypes types = All);
 
 public:
     int columnCount(const QModelIndex &pidx) const override;
@@ -100,6 +99,9 @@ public:
     void setRemarkKeys(const std::vector<GpgME::Key> &remarkKeys);
     std::vector<GpgME::Key> remarkKeys() const;
 
+protected:
+    bool modelResetInProgress();
+
 private:
     QVariant data(const GpgME::Key &key, int column, int role) const;
     QVariant data(const KeyGroup &group, int column, int role) const;
@@ -127,4 +129,3 @@ private:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Kleo::AbstractKeyListModel::ItemTypes)
 
-#endif /* __KLEOPATRA_MODELS_KEYLISTMODEL_H__ */
