@@ -4,19 +4,22 @@
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
     SPDX-FileCopyrightText: 2016 Andre Heinecke <aheinecke@gnupg.org>
+    SPDX-FileCopyrightText: 2021 g10 Code GmbH
+    SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_MODELS_USERIDLISTMODEL_H__
-#define __KLEOPATRA_MODELS_USERIDLISTMODEL_H__
-
-#include <QAbstractItemModel>
+#pragma once
 
 #include <kleo_export.h>
 
+#include <QAbstractItemModel>
+
 #include <gpgme++/key.h> // since Signature is nested in UserID...
 
+#include <memory>
+
 class UIDModelItem;
 
 namespace Kleo
@@ -26,6 +29,18 @@ class KLEO_EXPORT UserIDListModel : public QAbstractItemModel
 {
     Q_OBJECT
 public:
+    enum class Column {
+        Id,
+        Name,
+        Email,
+        ValidFrom,
+        ValidUntil,
+        Status,
+        Exportable,
+        Tags,
+        TrustSignatureDomain,
+    };
+
     explicit UserIDListModel(QObject *parent = nullptr);
     ~UserIDListModel() override;
 
@@ -53,9 +68,8 @@ public:
 private:
     GpgME::Key mKey;
     bool mRemarksEnabled = false;
-    UIDModelItem *mRootItem = nullptr;
+    std::unique_ptr<UIDModelItem> mRootItem;
 };
 
 }
 
-#endif /* __KLEOPATRA_MODELS_USERIDLISTMODEL_H__ */
